# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`artifactory`](#artifactory): Install and configure Artifactory.

#### Private Classes

* `artifactory::config`: Manage Artifactory configuration.
* `artifactory::install`: Call the configured installation class
* `artifactory::install::archive`: Install artifactory from archive
* `artifactory::install::package`: Install artifactory from package
* `artifactory::repo`: Pull in the platform specific repo classes
* `artifactory::repo::apt`: Setup APT repository on Debian-based distributions
* `artifactory::repo::yum`: Setup YUM repository on RedHat-based distributions
* `artifactory::service`: Configure the Artifactory system service.

## Classes

### <a name="artifactory"></a>`artifactory`

Install and configure Artifactory.

#### Parameters

The following parameters are available in the `artifactory` class:

* [`apt_baseurl`](#-artifactory--apt_baseurl)
* [`apt_baseurl_pro`](#-artifactory--apt_baseurl_pro)
* [`apt_key_id`](#-artifactory--apt_key_id)
* [`apt_key_source`](#-artifactory--apt_key_source)
* [`apt_repos`](#-artifactory--apt_repos)
* [`archive_data_dir`](#-artifactory--archive_data_dir)
* [`archive_install_dir`](#-artifactory--archive_install_dir)
* [`artifactory_home`](#-artifactory--artifactory_home)
* [`binary_provider_base_data_dir`](#-artifactory--binary_provider_base_data_dir)
* [`binary_provider_cache_dir`](#-artifactory--binary_provider_cache_dir)
* [`binary_provider_cache_maxsize`](#-artifactory--binary_provider_cache_maxsize)
* [`binary_provider_config_hash`](#-artifactory--binary_provider_config_hash)
* [`binary_provider_filesystem_dir`](#-artifactory--binary_provider_filesystem_dir)
* [`binary_provider_type`](#-artifactory--binary_provider_type)
* [`config_group`](#-artifactory--config_group)
* [`config_owner`](#-artifactory--config_owner)
* [`db_password`](#-artifactory--db_password)
* [`db_type`](#-artifactory--db_type)
* [`db_url`](#-artifactory--db_url)
* [`db_username`](#-artifactory--db_username)
* [`download_filename`](#-artifactory--download_filename)
* [`download_url_oss`](#-artifactory--download_url_oss)
* [`download_url_pro`](#-artifactory--download_url_pro)
* [`edition`](#-artifactory--edition)
* [`install_method`](#-artifactory--install_method)
* [`install_service_script`](#-artifactory--install_service_script)
* [`jdbc_driver_url`](#-artifactory--jdbc_driver_url)
* [`license_key`](#-artifactory--license_key)
* [`manage_repo`](#-artifactory--manage_repo)
* [`master_key`](#-artifactory--master_key)
* [`package_name`](#-artifactory--package_name)
* [`package_name_pro`](#-artifactory--package_name_pro)
* [`package_version`](#-artifactory--package_version)
* [`pool_max_active`](#-artifactory--pool_max_active)
* [`pool_max_idle`](#-artifactory--pool_max_idle)
* [`root_password`](#-artifactory--root_password)
* [`service_name`](#-artifactory--service_name)
* [`symlink_name`](#-artifactory--symlink_name)
* [`use_temp_db_secrets`](#-artifactory--use_temp_db_secrets)
* [`yum_baseurl`](#-artifactory--yum_baseurl)
* [`yum_baseurl_pro`](#-artifactory--yum_baseurl_pro)
* [`yum_gpgkey`](#-artifactory--yum_gpgkey)
* [`yum_gpgkey_pro`](#-artifactory--yum_gpgkey_pro)
* [`yum_name`](#-artifactory--yum_name)

##### <a name="-artifactory--apt_baseurl"></a>`apt_baseurl`

Data type: `Optional[String]`

Sets the URL of the APT repository.

Default value: `undef`

##### <a name="-artifactory--apt_baseurl_pro"></a>`apt_baseurl_pro`

Data type: `Optional[String]`

Sets the URL of the APT repository (Pro edition).

Default value: `undef`

##### <a name="-artifactory--apt_key_id"></a>`apt_key_id`

Data type: `Optional[String]`

Sets the ID of the APT repository key.

Default value: `undef`

##### <a name="-artifactory--apt_key_source"></a>`apt_key_source`

Data type: `Optional[String]`

Sets the URL of the APT repository.

Default value: `undef`

##### <a name="-artifactory--apt_repos"></a>`apt_repos`

Data type: `Optional[String]`

Sets the names of the APT repositories to enable.

Default value: `undef`

##### <a name="-artifactory--archive_data_dir"></a>`archive_data_dir`

Data type: `Stdlib::Absolutepath`

The Artifactory data directory that should be used for archive installations.

##### <a name="-artifactory--archive_install_dir"></a>`archive_install_dir`

Data type: `Stdlib::Absolutepath`

The Artifactory app directory that should be used for archive installations.

##### <a name="-artifactory--artifactory_home"></a>`artifactory_home`

Data type: `String`

Specifies the main directory.

##### <a name="-artifactory--binary_provider_base_data_dir"></a>`binary_provider_base_data_dir`

Data type: `Optional[String]`

The filestore base location. Defaults to '$ARTIFACTORY_HOME/data'.

Default value: `undef`

##### <a name="-artifactory--binary_provider_cache_dir"></a>`binary_provider_cache_dir`

Data type: `Optional[String]`

The location of the cache. This should be set to the $ARTIFACTORY_HOME
directory (not on NFS).

Default value: `undef`

##### <a name="-artifactory--binary_provider_cache_maxsize"></a>`binary_provider_cache_maxsize`

Data type: `Optional[Integer]`

This value specifies the maximum cache size (in bytes) to allocate for
caching BLOBs.

Default value: `undef`

##### <a name="-artifactory--binary_provider_config_hash"></a>`binary_provider_config_hash`

Data type: `Optional[Hash]`

A hash containing configuration options for the binary provider.

Default value: `undef`

##### <a name="-artifactory--binary_provider_filesystem_dir"></a>`binary_provider_filesystem_dir`

Data type: `Optional[String]`

If the `$binary_provider_type` is set to `filesystem`, this value specifies
the location of the binaries in combination with `$binary_provider_base_data_dir`.

Default value: `undef`

##### <a name="-artifactory--binary_provider_type"></a>`binary_provider_type`

Data type: `Optional[Enum['filesystem', 'fullDb', 'cachedFS', 'fullDbDirect', 's3']]`

Optional setting for the binary storage provider. The type of database to
configure. Valid values are 'filesystem', 'fullDb', 'cachedFS', 'S3'.
Defaults to 'filesystem'.

Default value: `undef`

##### <a name="-artifactory--config_group"></a>`config_group`

Data type: `String`

Specifies the group owner of the configuration files.

##### <a name="-artifactory--config_owner"></a>`config_owner`

Data type: `String`

Specifies the owner of the configuration files.

##### <a name="-artifactory--db_password"></a>`db_password`

Data type: `Optional[String]`

The password for the database account. Only required for database configuration.

Default value: `undef`

##### <a name="-artifactory--db_type"></a>`db_type`

Data type: `Optional[Enum['derby', 'mariadb', 'mssql', 'mysql', 'oracle', 'postgresql']]`

The type of database to configure. Only required for database configuration.

Default value: `undef`

##### <a name="-artifactory--db_url"></a>`db_url`

Data type: `Optional[String]`

The url of the database. Only required for database configuration.

Default value: `undef`

##### <a name="-artifactory--db_username"></a>`db_username`

Data type: `Optional[String]`

The username for the database account. Only required for database configuration.

Default value: `undef`

##### <a name="-artifactory--download_filename"></a>`download_filename`

Data type: `String`

The filename of the archive distribution.

##### <a name="-artifactory--download_url_oss"></a>`download_url_oss`

Data type: `String`

The download URL for the open-source edition.

##### <a name="-artifactory--download_url_pro"></a>`download_url_pro`

Data type: `String`

The download URL for the pro edition.

##### <a name="-artifactory--edition"></a>`edition`

Data type: `Enum['oss', 'pro', 'enterprise']`

Specifies the Artifactory edition/license.

##### <a name="-artifactory--install_method"></a>`install_method`

Data type: `String`

Whether to use a package or an archive to install artifactory.

##### <a name="-artifactory--install_service_script"></a>`install_service_script`

Data type: `String`

Path to the installation script of the archive distribution.

##### <a name="-artifactory--jdbc_driver_url"></a>`jdbc_driver_url`

Data type: `Optional[String]`

Sets the download location for the jdbc driver.

Default value: `undef`

##### <a name="-artifactory--license_key"></a>`license_key`

Data type: `Optional[String]`

Specifies the license key (only commercial editions).

Default value: `undef`

##### <a name="-artifactory--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether to setup required repos or disable repo management.

##### <a name="-artifactory--master_key"></a>`master_key`

Data type: `Optional[String]`

The master key that Artifactory uses to connect to the database.
If specified, it ensures that if the node terminates, a new one
can be spun up that can connect to the same database as before.
Otherwise, Artifactory will generate a new master key on first run.

Default value: `undef`

##### <a name="-artifactory--package_name"></a>`package_name`

Data type: `String`

Sets the package name to install.

##### <a name="-artifactory--package_name_pro"></a>`package_name_pro`

Data type: `String`

Sets the package name to install (Pro edition).

##### <a name="-artifactory--package_version"></a>`package_version`

Data type: `String`

Specifies the package version. It is highly recommended to set it to
a real version number. Setting the value to `present` may lead to a
broken config.

##### <a name="-artifactory--pool_max_active"></a>`pool_max_active`

Data type: `Optional[Integer]`

Maximum number of pooled database connections.

Default value: `undef`

##### <a name="-artifactory--pool_max_idle"></a>`pool_max_idle`

Data type: `Optional[Integer]`

Maximum number of pooled idle database connections.

Default value: `undef`

##### <a name="-artifactory--root_password"></a>`root_password`

Data type: `String`

Sets the root password for Puppet managed mysql database instance.

##### <a name="-artifactory--service_name"></a>`service_name`

Data type: `String`

Specifies the name of the Artifactory system service.

##### <a name="-artifactory--symlink_name"></a>`symlink_name`

Data type: `String`

Controls the name of a version-independent symlink for the archive
installation. It will always point to the release specified by `$package_version`.

##### <a name="-artifactory--use_temp_db_secrets"></a>`use_temp_db_secrets`

Data type: `Boolean`

Set to `true` to delete the temporary db.properties file on service start.
Set to `false` to persist the file in `$artifactory_home/etc/db.properties`,
which will allow to add database and storage options without Puppet
touching it.

##### <a name="-artifactory--yum_baseurl"></a>`yum_baseurl`

Data type: `Optional[String]`

Sets the URL of the yum repository.

Default value: `undef`

##### <a name="-artifactory--yum_baseurl_pro"></a>`yum_baseurl_pro`

Data type: `Optional[String]`

Sets the URL of the yum repository (Pro edition).

Default value: `undef`

##### <a name="-artifactory--yum_gpgkey"></a>`yum_gpgkey`

Data type: `Optional[String]`

Sets the gpgkey URL of the yum repository.

Default value: `undef`

##### <a name="-artifactory--yum_gpgkey_pro"></a>`yum_gpgkey_pro`

Data type: `Optional[String]`

Sets the gpgkey URL of the yum repository (Pro edition).

Default value: `undef`

##### <a name="-artifactory--yum_name"></a>`yum_name`

Data type: `Optional[String]`

Sets the name of the yum repository.

Default value: `undef`

